@@ -421,6 +421,7 @@ int k9vamps::check_video_packet (uchar *ptr) {
 // from a very short time) so a dual CPU box does not give an advantage
 // returns size of evaporated GOP
 int k9vamps::requant (uchar *dst, uchar *src, int n, float fact) {
+    if (n==0) return 0;
     int rv;
     if (! m_requant->running()) {
         m_requant->initvar();
@@ -636,9 +637,11 @@ void k9vamps::vap_leader () {
 
             if (14 + data_length != SECT_SIZE - 6)
                 fatal (QString("Bad padding packet length at %1: %2").arg(rtell (ptr)).arg(data_length));
+  	    //JMP:à vérifier 
+  	    skip (SECT_SIZE);
 
             break;
-
+	   
         default:
 	 //   fatal("Encountered stream ID %02x at %llu, "
          //          "probably bad MPEG2 program stream", id, rtell (ptr));
@@ -679,6 +682,7 @@ void k9vamps::vap_trailer (int length) {
 
             if (14 + data_length != SECT_SIZE - 6)
                 fatal (QString("Bad padding packet length at %1: %2").arg(rtell (ptr)).arg(data_length));
+	    skip (SECT_SIZE);
         } else {
             copy (SECT_SIZE);
         }
@@ -935,7 +939,8 @@ void k9vamps::vap_phase2 (int seq_length) {
 
             if (14 + data_length != SECT_SIZE - 6)
                 fatal (QString("Bad padding packet length at %1: %2").arg(rtell (ptr)).arg(data_length));
-
+	    //JMP: à vérifier
+  	    skip (SECT_SIZE);
             break;
 
         default:
