@@ -26,6 +26,7 @@
 #include "k9ifo2.h"
 #include <qapplication.h>
 #include <klocale.h>
+#include <kdebug.h>
 
 #include <sys/stat.h>
 
@@ -111,11 +112,10 @@ k9DVD::k9DVD(QObject  *parent, const char *name,const QStringList args)  {
     m_lvideoWidth.append("352");
     m_lvideoWidth.append("352");
 
-    m_lpermittedDf.append("Pan&Scan");
-    m_lpermittedDf.append("Letterbox");
-    m_lpermittedDf.append("Pan&Scan");
-    m_lpermittedDf.append("Letterbox");
-    m_lpermittedDf.append("?");
+    m_lpermittedDf.append("");
+    m_lpermittedDf.append("noletterbox");
+    m_lpermittedDf.append("nopanscan");
+    m_lpermittedDf.append("noletterbox & nopanscan");
 
     m_laudioFormat.append("ac3");
     m_laudioFormat.append("?");
@@ -288,7 +288,7 @@ int k9DVD::scandvd (const QString & device,bool _quickScan) {
     subp_attr_t *subp_attr;
     pgc_t *pgc;
     int i, j,  ltitles, cell, vts_ttn, title_set_nr;
-    char lang_code[2];
+    char lang_code[3];
     int has_title = 0;
     int max_length = 0;
     bool ok;
@@ -358,7 +358,7 @@ int k9DVD::scandvd (const QString & device,bool _quickScan) {
 
     ltitles = ifo_zero->tt_srpt->nr_of_srpts;
     m_titleCount = 0;
-    has_title = get_title_name(device.latin1(), ctitle);
+    has_title = get_title_name(device.utf8(), ctitle);
 
     vmgi_mat = ifo_zero->vmgi_mat;
     m_titlesetCount = vmgi_mat->vmg_nr_of_title_sets;
@@ -465,7 +465,7 @@ int k9DVD::scandvd (const QString & device,bool _quickScan) {
                         if (audio_attr->audio_format==6)
                             l_auds->m_streamId +=8;
                         //JMPaudio_attr = &vtsi_mat->vts_audio_attr[l_auds->id-1];
-                        sprintf(lang_code, "%c%c", audio_attr->lang_code>>8, audio_attr->lang_code & 0xff);
+                        snprintf(lang_code,3, "%c%c", audio_attr->lang_code>>8, audio_attr->lang_code & 0xff);
                         if (!lang_code[0]) {
                             lang_code[0] = 'x';
                             lang_code[1] = 'x';
@@ -500,7 +500,7 @@ int k9DVD::scandvd (const QString & device,bool _quickScan) {
                 k9DVDChapter *l_pchap=NULL;
                 for (i=0; i<pgc->nr_of_programs; i++) {
                     int second=0, minute=0, hour=0, tmp;
-                    char hex[2];
+                    char hex[3];
                     int next = pgc->program_map[i+1];
                     unsigned long sectors = 0;
                     l_chap = l_track->getChapter(i);
@@ -519,11 +519,11 @@ int k9DVD::scandvd (const QString & device,bool _quickScan) {
                         int startSect=pgc->cell_playback[cell].first_sector;
                         l_chap->startSectors.append(startSect);
 
-                        sprintf(hex, "%02x", pgc->cell_playback[cell].playback_time.second);
+                        snprintf(hex,3, "%02x", pgc->cell_playback[cell].playback_time.second);
                         tmp = second + atoi(hex);
                         minute = minute + (tmp / 60);
                         second = tmp % 60;
-                        sprintf(hex, "%02x", pgc->cell_playback[cell].playback_time.minute);
+                        snprintf(hex,3, "%02x", pgc->cell_playback[cell].playback_time.minute);
                         tmp = minute + atoi(hex);
                         hour = hour + (tmp / 60);
                         minute = tmp % 60;
@@ -593,23 +593,25 @@ int k9DVD::scandvd (const QString & device,bool _quickScan) {
                         unsigned char subpc;
                         subpc=pgc->subp_control[i]>>24;
                         if ((subpc & 0x80)==0x80) {
-                            l_sub->id=1;
-                            if ((subpc &0x1F) !=0)
-                                l_sub->id = 1+ (subpc & 0x1F);
-                            subpc=pgc->subp_control[i]>>16;
-                            if ((subpc &0x1F) !=0)
-                                l_sub->id = 1+ (subpc & 0x1F);
-                            subpc=pgc->subp_control[i]>>8;
-                            if ((subpc &0x1F) !=0)
-                                l_sub->id = 1+ (subpc & 0x1F);
-                            subpc=pgc->subp_control[i];
-                            if ((subpc &0x1F) !=0)
-                                l_sub->id = 1+ (subpc & 0x1F);
+                            if (l_track->aspectRatio=="4:3") {
+                                l_sub->id.append(1+ (subpc & 0x1F));
+                            } else {
+                                subpc=(pgc->subp_control[i]>>16) & 0x1F;
+                                l_sub->id.append(1+ subpc);
+                                subpc=(pgc->subp_control[i]>>8) & 0x1F;
+                                if (! l_sub->id.contains(1+ subpc) && ! l_track->DF.contains("noletterbox"))
+                                    l_sub->id.append(1+ subpc);
+                                subpc=pgc->subp_control[i] & 0x1F;
+                                if (! l_sub->id.contains(1+ subpc) && ! l_track->DF.contains("nopanscan"))
+                                    l_sub->id.append(1+ subpc);
+                            }
+                            kdDebug() << "VTS: " << l_track->VTS << " TTN: " << l_track->TTN << \
+                                         " Subtitle " << i+1 << ": " << l_sub->id << " " << l_sub->language << \
+                                         " " << l_sub->content << endl;
                         }
                         l_track->subPictureCount++;
-                        //subp_attr = &vtsi_mat->vts_subp_attr[i];
-                        subp_attr = &vtsi_mat->vts_subp_attr[l_sub->id -1];
-                        sprintf(lang_code, "%c%c", subp_attr->lang_code>>8, subp_attr->lang_code & 0xff);
+                        subp_attr = &vtsi_mat->vts_subp_attr[i];
+                        snprintf(lang_code,3, "%c%c", subp_attr->lang_code>>8, subp_attr->lang_code & 0xff);
                         if (!lang_code[0]) {
                             lang_code[0] = 'x';
                             lang_code[1] = 'x';
@@ -808,7 +810,7 @@ void k9DVD::calcStreamSize(k9DVDTitle & track) {
                 break;
             int id=streamList[x].id;
             if ( (id >=0x20) && (id <=0x3f)) {
-                if (  (id - 0x20 +1) ==l_sub->id) {
+                if (  l_sub->id.contains(id - 0x20 +1) ) {
                     l_sub->size_mb = streamList[x].size_mb;
                     break;
                 }
