@@ -25,10 +25,11 @@
 #include "k9progress.h"
 
 #include <qdom.h>
-#include <qprocess.h>
+#include "k9process.h"
 #include <qdatastream.h>
 #include <qprogressdialog.h>
 #include <klocale.h>
+#include <ktempfile.h>
 /**
   *@author
   */
@@ -44,6 +45,7 @@ public:
   virtual void author();
   virtual void setburnDVD( const bool& _newVal);
   virtual const bool& getburnDVD();
+  virtual QWidget *getDialog(){return progress;};
 private: // Private attributes
   /**  */
   QTime *time;
@@ -51,7 +53,7 @@ private: // Private attributes
   double factor;
   QDomDocument *xml;
   QString lastMsg,totSize,inject;
-  QProcess *proc;
+  k9Process *proc;
   QString workDir;
   k9Progress *progress;
   bool cancelled;
@@ -62,7 +64,8 @@ private: // Private attributes
   uint64_t m_forced,m_forcedsh;
   uint32_t m_copied,m_lastPos;
   uint64_t m_totalPartSize;
-  void clearOutput(QString name);
+  KTempFile *m_xml,*m_inject;
+  QPtrList <KTempFile> files;
   void createXML();
   void addTitle(QDomElement &root, k9DVDTitle *title);
   void createMenus(bool preview);
@@ -71,8 +74,8 @@ private: // Private attributes
   void spumux();
 private slots: // Private slots
   /** No descriptions */
-  void DVDAuthorStderr();
-  void DVDAuthorStdout();
+  void DVDAuthorStderr(KProcess *proc, char *buffer, int buflen);
+  void DVDAuthorStdout(KProcess *proc, char *buffer, int buflen);
 
   /** No descriptions */
   void stopProcess();
