@@ -74,6 +74,7 @@ public:
     virtual void execute();
     virtual bool geterror();
     virtual void setWithMenus(bool _value);
+    virtual QWidget *getDialog() {return (QWidget*)backupDlg;};
 public  slots:
     void getOutput(uchar *buffer,uint32_t size);
 
@@ -98,6 +99,7 @@ private:
     k9Cell *currCell,*cellOut;//,*currCopyCell;
     k9CellCopyList *m_cellCopyList;
     uint32_t m_position,m_vmgSize;
+    bool m_preserve;
     //uint64_t m_inbytes,m_outbytes;
     k9TitleSetList titleSets;
     float argFactor;
@@ -123,7 +125,6 @@ private:
     k9Vobu * remapVobu(uint32_t *value);
     k9Vobu * remapOffset(uint32_t _sector,uint32_t *offset,int dir);
     k9BackupDlg *backupDlg;
-    void clearOutput(QString name);
     uint  getLastCell(k9CellCopyList *_cellCopyList,uint _index);
     void calcFactor();
     void forceFactor(double _factor);
