@@ -46,16 +46,12 @@
 #include <qstatusbar.h>
 #include <kpushbutton.h>
 #include <kiconloader.h>
-#include <qaction.h>
-#include <ktoolbar.h>
-#include <qframe.h>
 #include <qcheckbox.h>
 #include <qmenubar.h>
 #include <qlabel.h>
 #include <qpixmap.h>
 #include <qspinbox.h>
 #include <qpainter.h>
-#include <qfont.h>
 #include <kdirselectdialog.h>
 #include <kio/global.h>
 #include <kio/job.h>
@@ -63,9 +59,6 @@
 #include <kdiskfreesp.h>
 #include <qvaluelist.h>
 #include <kdeversion.h>
-#include <qlistbox.h>
-#include <qtoolbox.h>
-#include <qregion.h>
 #include <qbitmap.h>
 
 
@@ -95,10 +88,11 @@ k9DVDListItem::k9DVDListItem(QObject *DVD,ckLvItem *List,eStreamType type)
   streamType=type;
 }
 
-k9Main::k9Main(QWidget* parent, const char* name, const QStringList &sl)
+k9Main::k9Main(QWidget* parent, const char* name, k9CdDrives *_drives)
     : MainDlg(parent,name),pxVideo((const char **) img_video), pxSound((const char **) img_sound),
     pxText((const char **) img_text)
 {
+  drives=_drives;
   m_parent=(k9Copy*)parent;
   QImage img;
   img.loadFromData( img_chapter, sizeof( img_chapter ), "PNG" );
@@ -117,8 +111,8 @@ k9Main::k9Main(QWidget* parent, const char* name, const QStringList &sl)
   listView1->setDefaultRenameAction(QListView::Accept);
   //    KStandardDirs kd;
   m_prefOutput=locateLocal("tmp","k9copy/",true); //kd.findResource("tmp","");
-  connect(&drives,SIGNAL(deviceAdded( k9CdDrive*)),this,SLOT(deviceAdded( k9CdDrive* )));
-  connect(&drives,SIGNAL(deviceRemoved( k9CdDrive*)),this,SLOT(deviceRemoved( k9CdDrive* )));
+  connect(drives,SIGNAL(deviceAdded( k9CdDrive*)),this,SLOT(deviceAdded( k9CdDrive* )));
+  connect(drives,SIGNAL(deviceRemoved( k9CdDrive*)),this,SLOT(deviceRemoved( k9CdDrive* )));
 
   readSettings();
   bInputOpen->setPixmap(SmallIcon("fileopen"));
@@ -175,7 +169,7 @@ int ckLvItem::compare ( QListViewItem * i, int col, bool ascending ) const
       }
       if (streamType==SUB)
       {
-        id+=((k9DVDSubtitle*)l->stream)->getID();
+        id+=((k9DVDSubtitle*)l->stream)->getID().first();
       }
 
       if (litem->streamType==AUD)
@@ -184,7 +178,7 @@ int ckLvItem::compare ( QListViewItem * i, int col, bool ascending ) const
       }
       if (litem->streamType==SUB)
       {
-        id2+=((k9DVDSubtitle*)litem->stream)->getID();
+        id2+=((k9DVDSubtitle*)litem->stream)->getID().first();
       }
 
 
@@ -381,22 +375,28 @@ void k9Main::Copy()
   }
   setDVDSize();
   updateSelection();
+  
+  QString outputDir=m_prefOutput;
+  bool burn=false;
 
   if (cbOutputDev->currentItem() ==0)
   {
     filename=KFileDialog::getSaveFileName (QDir::homeDirPath(),"*.iso", 0,i18n("Save image to disk"));
     if (filename =="")
       return;
+  } else if (cbOutputDev->currentItem()==1) {
+    outputDir= KFileDialog::getExistingDirectory(QDir::homeDirPath());
+    if (outputDir=="")
+       return;
   }
 
   if (getFreeSpace( m_prefOutput) <  m_prefSize)
   {
-    if (KMessageBox::warningContinueCancel (this, i18n("Insuffisant disk space on %1\n%2 mb expected.").arg(m_prefOutput).arg(m_prefSize),i18n("DVD Copy"))==KMessageBox::Cancel)
+    if (KMessageBox::warningContinueCancel (this, i18n("Insufficient disk space on %1\n%2 mb expected.").arg(m_prefOutput).arg(m_prefSize),i18n("DVD Copy"))==KMessageBox::Cancel)
       return;
   }
   stopPreview();
   changeStatusbar( i18n("Backup in progress"),sbMessage);
-  bool burn=false;
   if (!m_useDvdAuthor || withMenus())
   {
     //copy with k9DVDBackup
@@ -406,7 +406,7 @@ void k9Main::Copy()
     k9DVDBackup *backup=new k9DVDBackup(dvd,"backup");
     
     setProgressWindow(backup->getDialog());
-    backup->setOutput(m_prefOutput);
+    backup->setOutput(outputDir);
     backup->setDevice(dvd->getDevice());
     backup->setWithMenus( withMenus());
     backup->execute();
@@ -421,7 +421,7 @@ void k9Main::Copy()
     k9DVDAuthor *b=new k9DVDAuthor(dvd,"dvdauthor");
     setProgressWindow( b->getDialog());
     m_playbackOptions->setSequence();
-    b->setworkDir(m_prefOutput);
+    b->setworkDir(outputDir);
     b->author();
     if (!b->getError())
       burn=true;
@@ -430,7 +430,7 @@ void k9Main::Copy()
     delete b;
   }
 
-  if (burn)
+  if (burn && cbOutputDev->currentItem()!=1)
   {
     changeStatusbar(i18n("Burning DVD"),sbMessage);
 
@@ -442,9 +442,9 @@ void k9Main::Copy()
     b.setAutoBurn(m_prefAutoBurn);
     b.setvolId(dvd->getDVDTitle());
     b.setSpeed( cbBurnSpeed->currentText());
-    if (cbOutputDev->currentItem() !=0)
+    if (cbOutputDev->currentItem() >1)
     {
-      k9CdDrive * drive=(k9CdDrive*)recorderList.at(cbOutputDev->currentItem()-1);
+      k9CdDrive * drive=(k9CdDrive*)recorderList.at(cbOutputDev->currentItem()-2);
       b.setburnDevice(drive->device);
       closeDVD();
       if (dvd->getDevice()== drive->device)
@@ -481,7 +481,7 @@ void k9Main::removeProgressWindow() {
 void k9Main::eject()
 {
   closeDVD();
-  drives.eject( getDevice(cbInputDev));
+  drives->eject( getDevice(cbInputDev));
 }
 
 
@@ -1152,7 +1152,7 @@ void k9Main::CreateMP4()
     {
       QString name;
       if (filename=="")
-         filename=KFileDialog::getSaveFileName (QDir::homeDirPath(),"*.avi", 0,i18n("Save file to disk"));
+         filename=KFileDialog::getSaveFileName (QDir::homeDirPath(),"*.avi|Audio Video Interleave (*.avi)\n*.mpg|MPEG-1 and MPEG-2 systems (*.mpg)\n*.mp4|MPEG-4 format (*.mp4)\n*.asf|Advanced Streaming Format (*.asf)\n*.swf|Adobe Flash (*.swf)\n*.flv|Adobe Flash video files (*.flv)\n*.rm|RealVideo (*.rm)\n*.mov|QuickTime (*.mov)", 0,i18n("Save file to disk"));
       if (filename=="")
          break;
     
@@ -1210,7 +1210,7 @@ void k9Main::deviceRemoved(k9CdDrive *_drive) {
   
   i=recorderList.find(_drive);
   recorderList.remove( i);
-  cbOutputDev->removeItem(i+1);  
+  cbOutputDev->removeItem(i+2);  
 
 }
 
@@ -1245,8 +1245,9 @@ void k9Main::readDrives()
   driveList.clear();
   recorderList.clear();
   cbOutputDev->insertItem(i18n("ISO Image"));
+  cbOutputDev->insertItem(i18n("Folder"));
   
-  drives.scanDrives();
+  drives->scanDrives();
 
 }
 
@@ -1426,7 +1427,7 @@ void k9Main::setOutput(QString _output)
     //        qDebug ("output=" +c);
     if (c==_output)
     {
-      cbOutputDev->setCurrentItem(i+1);
+      cbOutputDev->setCurrentItem(i+2);
       break;
     }
   }
@@ -1474,3 +1475,8 @@ bool k9Main::withMenus()
 }
 
 #include "k9main.moc"
+
+
+void k9Main::setDrives(k9CdDrives* _value) {
+    drives = _value;
+}
